@@ -8,7 +8,7 @@ tfplot <- function(x, ...)  UseMethod("tfplot")
 tfplot.default <- function(x, ..., tf=tfspan(x , ...), start=tfstart(tf), end=tfend(tf),
        series=seq(nseries(x)), 
        Title=NULL, title=Title, subtitle=NULL,
-       lty = 1:5, lwd = 1, pch = NULL, col = 1:6, cex = NULL,
+       lty = 1:5, lwd = 1, pch = 1, col = 1:6, cex = NULL,
        xlab=NULL, ylab=seriesNames(x), xlim = NULL, ylim = NULL,
        graphs.per.page=5, par=NULL, mar=par()$mar, reset.screen=TRUE,
        lastObs=FALSE, source=NULL,
@@ -71,7 +71,7 @@ tfplot.default <- function(x, ..., tf=tfspan(x , ...), start=tfstart(tf), end=tf
  }
 
 tfOnePlot <- function(x, tf=tframe(x), start=tfstart(tf), end=tfend(tf), 
-         Title=NULL, title=Title, subtitle=NULL, lty=1:5, lwd=1, pch=NULL, col=1:6, cex=NULL,
+         Title=NULL, title=Title, subtitle=NULL, lty=1:5, lwd=1, pch=1, col=1:6, cex=NULL,
         xlab=NULL, ylab=NULL, xlim=NULL, ylim=NULL, par=NULL,
 	lastObs=FALSE,  
 	source=NULL,
